import { JSONLDObject } from '@chharvey/requirejson'
			/**
			 * Boolean: True or False.
			 *
			 * @see http://schema.org/Boolean
			 */
			export type Boolean = boolean
		
			/**
			 * A date value in ISO 8601 date format.
			 *
			 * @see http://schema.org/Date
			 */
			export type Date = string
		
			/**
			 * A combination of date and time of day in the form [-]CCYY-MM-DDThh:mm:ss[Z|(+|-)hh:mm] (see Chapter 5.4 of ISO 8601).
			 *
			 * @see http://schema.org/DateTime
			 */
			export type DateTime = string
		
			/**
			 * Data type: Integer.
			 *
			 * @see http://schema.org/Integer
			 */
			export type Integer = number
		
			/**
			 * Data type: Number.
			 *
			 * @see http://schema.org/Number
			 */
			export type Number = number
		
			/**
			 * Data type: Text.
			 *
			 * @see http://schema.org/Text
			 */
			export type Text = string
		
			/**
			 * A point in time recurring on multiple days in the form hh:mm:ss[Z|(+|-)hh:mm] (see XML schema for details).
			 *
			 * @see http://schema.org/Time
			 */
			export type Time = string
		
			/**
			 * Data type: URL.
			 *
			 * @see http://schema.org/URL
			 */
			export type URL = string
		
			/**
			 * An accommodation is a place that can accommodate human beings, e.g. a hotel room, a camping pitch, or a meeting room.
			 *
			 * 
			 * 
			 * @see http://schema.org/Accommodation
			 */
			export interface Accommodation extends Place {
				
			}
		
			/**
			 * An action performed by a direct agent and indirect participants upon a direct object. Optionally happens at a location with the help of an inanimate instrument. The execution of the action may produce a result. Specific action sub-type documentation specifies the exact expectation of each argument/role.
			 *
			 * 
			 * *(Non-Normative):* May appear as values of:
 * - {@link potentialAction_type}

			 * @see http://schema.org/Action
			 */
			export interface Action extends Thing {
				
					agent?: agent_type
				
					endTime?: endTime_type
				
					location?: location_type
				
					startTime?: startTime_type
				
			}
		
			/**
			 * A geographical region, typically under the jurisdiction of a particular government.
			 *
			 * *(Non-Normative):* Known subclasses:
 * - {@link City}
 * - {@link Country}
 * - {@link State}

			 * 
			 * @see http://schema.org/AdministrativeArea
			 */
			export interface AdministrativeArea extends Place {
				
			}
		
			/**
			 * When a single product is associated with multiple offers (for example, the same pair of shoes is offered by different merchants), then AggregateOffer can be used.
			 *
			 * 
			 * 
			 * @see http://schema.org/AggregateOffer
			 */
			export interface AggregateOffer extends Offer {
				
					offerCount?: offerCount_type
				
					offers?: offers_type
				
			}
		
			/**
			 * A brand is a name used by an organization or business person for labeling a product, product group, or similar.
			 *
			 * 
			 * *(Non-Normative):* May appear as values of:
 * - {@link brand_type}

			 * @see http://schema.org/Brand
			 */
			export interface Brand extends Intangible {
				
					logo?: logo_type
				
			}
		
			/**
			 * A city or town.
			 *
			 * 
			 * 
			 * @see http://schema.org/City
			 */
			export interface City extends AdministrativeArea {
				
			}
		
			/**
			 * A compound price specification is one that bundles multiple prices that all apply in combination for different dimensions of consumption. Use the name property of the attached unit price specification for indicating the dimension of a price component (e.g. “electricity” or “final cleaning”).
			 *
			 * 
			 * 
			 * @see http://schema.org/CompoundPriceSpecification
			 */
			export interface CompoundPriceSpecification extends PriceSpecification {
				
					priceComponent?: priceComponent_type
				
			}
		
			/**
			 * A contact point—for example, a Customer Complaints department.
			 *
			 * *(Non-Normative):* Known subclasses:
 * - {@link PostalAddress}

			 * *(Non-Normative):* May appear as values of:
 * - {@link contactPoint_type}

			 * @see http://schema.org/ContactPoint
			 */
			export interface ContactPoint extends StructuredValue {
				
					email?: email_type
				
					telephone?: telephone_type
				
			}
		
			/**
			 * A country.
			 *
			 * 
			 * 
			 * @see http://schema.org/Country
			 */
			export interface Country extends AdministrativeArea {
				
			}
		
			/**
			 * The most generic kind of creative work, including books, movies, photographs, software programs, etc.
			 *
			 * *(Non-Normative):* Known subclasses:
 * - {@link HowTo}
 * - {@link MediaObject}
 * - {@link NewsArticle}
 * - {@link PublicationIssue}
 * - {@link WebPage}
 * - {@link WebPageElement}
 * - {@link WebSite}

			 * *(Non-Normative):* May appear as values of:
 * - {@link hasPart_type}
 * - {@link isPartOf_type}
 * - {@link mainEntityOfPage_type}

			 * @see http://schema.org/CreativeWork
			 */
			export interface CreativeWork extends Thing {
				
					creator?: creator_type
				
					dateCreated?: dateCreated_type
				
					dateModified?: dateModified_type
				
					datePublished?: datePublished_type
				
					funder?: funder_type
				
					hasPart?: hasPart_type
				
					headline?: headline_type
				
					isPartOf?: isPartOf_type
				
					keywords?: keywords_type
				
					mainEntity?: mainEntity_type
				
					offers?: offers_type
				
					position?: position_type
				
					sponsor?: sponsor_type
				
					text?: text_type
				
					thumbnailUrl?: thumbnailUrl_type
				
					publisher?: publisher_type
				
			}
		
			/**
			 * An event happening at a certain time and location, such as a concert, lecture, or festival.
			 *
			 * 
			 * *(Non-Normative):* May appear as values of:
 * - {@link event_type}
 * - {@link subEvent_type}
 * - {@link superEvent_type}

			 * @see http://schema.org/Event
			 */
			export interface Event extends Thing {
				
					endDate?: endDate_type
				
					funder?: funder_type
				
					location?: location_type
				
					offers?: offers_type
				
					organizer?: organizer_type
				
					performer?: performer_type
				
					sponsor?: sponsor_type
				
					startDate?: startDate_type
				
					subEvent?: subEvent_type
				
					superEvent?: superEvent_type
				
			}
		
			/**
			 * The geographic coordinates of a place or event.
			 *
			 * 
			 * *(Non-Normative):* May appear as values of:
 * - {@link geo_type}

			 * @see http://schema.org/GeoCoordinates
			 */
			export interface GeoCoordinates extends StructuredValue {
				
					address?: address_type
				
					elevation?: elevation_type
				
					latitude?: latitude_type
				
					longitude?: longitude_type
				
			}
		
			/**
			 * Instructions that explain how to achieve a result by performing a sequence of steps.
			 *
			 * *(Non-Normative):* Known subclasses:
 * - {@link Recipe}

			 * 
			 * @see http://schema.org/HowTo
			 */
			export interface HowTo extends CreativeWork {
				
					yield?: yield_type
				
			}
		
			/**
			 * An image file.
			 *
			 * 
			 * *(Non-Normative):* May appear as values of:
 * - {@link image_type}
 * - {@link logo_type}
 * - {@link photo_type}

			 * @see http://schema.org/ImageObject
			 */
			export interface ImageObject extends MediaObject {
				
			}
		
			/**
			 * A utility class that serves as the umbrella for a number of 'intangible' things such as quantities, structured values, etc.
			 *
			 * *(Non-Normative):* Known subclasses:
 * - {@link Brand}
 * - {@link ItemList}
 * - {@link JobPosting}
 * - {@link ListItem}
 * - {@link Offer}
 * - {@link Rating}
 * - {@link StructuredValue}

			 * 
			 * @see http://schema.org/Intangible
			 */
			export interface Intangible extends Thing {
				
			}
		
			/**
			 * A list of items of any sort.
			 *
			 * 
			 * 
			 * @see http://schema.org/ItemList
			 */
			export interface ItemList extends Intangible {
				
					itemListElement?: itemListElement_type
				
					numberOfItems?: numberOfItems_type
				
			}
		
			/**
			 * A listing that describes a job opening in a certain organization.
			 *
			 * 
			 * 
			 * @see http://schema.org/JobPosting
			 */
			export interface JobPosting extends Intangible {
				
					hiringOrganization?: hiringOrganization_type
				
					jobLocation?: jobLocation_type
				
					responsibilities?: responsibilities_type
				
					title?: title_type
				
			}
		
			/**
			 * A list item.
			 *
			 * 
			 * *(Non-Normative):* May appear as values of:
 * - {@link itemListElement_type}
 * - {@link nextItem_type}
 * - {@link previousItem_type}

			 * @see http://schema.org/ListItem
			 */
			export interface ListItem extends Intangible {
				
					item?: item_type
				
					nextItem?: nextItem_type
				
					position?: position_type
				
					previousItem?: previousItem_type
				
			}
		
			/**
			 * A particular physical business or branch of an organization. Examples of LocalBusiness include a restaurant, a particular branch of a restaurant chain, a branch of a bank, a medical practice, a club, a bowling alley, etc.
			 *
			 * *(Non-Normative):* Known subclasses:
 * - {@link LodgingBusiness}

			 * 
			 * @see http://schema.org/LocalBusiness
			 */
			export interface LocalBusiness extends Organization {
				
					currenciesAccepted?: currenciesAccepted_type
				
					openingHours?: openingHours_type
				
					paymentAccepted?: paymentAccepted_type
				
					priceRange?: priceRange_type
				
			}
		
			/**
			 * A lodging business, such as a motel, hotel, or inn.
			 *
			 * 
			 * 
			 * @see http://schema.org/LodgingBusiness
			 */
			export interface LodgingBusiness extends LocalBusiness {
				
					availableLanguage?: availableLanguage_type
				
					checkinTime?: checkinTime_type
				
					checkoutTime?: checkoutTime_type
				
					petsAllowed?: petsAllowed_type
				
					starRating?: starRating_type
				
			}
		
			/**
			 * A media object, such as an image, video, or audio object embedded in a web page or a downloadable dataset i.e. DataDownload.
			 *
			 * *(Non-Normative):* Known subclasses:
 * - {@link ImageObject}

			 * 
			 * @see http://schema.org/MediaObject
			 */
			export interface MediaObject extends CreativeWork {
				
					height?: height_type
				
					width?: width_type
				
			}
		
			/**
			 * A NewsArticle is an article whose content reports news, or provides background context and supporting materials for understanding the news.
			 *
			 * 
			 * 
			 * @see http://schema.org/NewsArticle
			 */
			export interface NewsArticle extends CreativeWork {
				
			}
		
			/**
			 * An offer to transfer some rights to an item or to provide a service—for example, an offer to sell tickets to an event, to rent the DVD of a movie, to stream a TV show over the internet, to repair a motorcycle, or to loan a book.
			 *
			 * *(Non-Normative):* Known subclasses:
 * - {@link AggregateOffer}

			 * *(Non-Normative):* May appear as values of:
 * - {@link makesOffer_type}
 * - {@link offers_type}

			 * @see http://schema.org/Offer
			 */
			export interface Offer extends Intangible {
				
					availabilityStarts?: availabilityStarts_type
				
					availabilityEnds?: availabilityEnds_type
				
					offeredBy?: offeredBy_type
				
					price?: price_type
				
					priceCurrency?: priceCurrency_type
				
					priceSpecification?: priceSpecification_type
				
			}
		
			/**
			 * An organization such as a school, NGO, corporation, club, etc.
			 *
			 * *(Non-Normative):* Known subclasses:
 * - {@link LocalBusiness}

			 * *(Non-Normative):* May appear as values of:
 * - {@link affiliation_type}
 * - {@link agent_type}
 * - {@link brand_type}
 * - {@link creator_type}
 * - {@link funder_type}
 * - {@link hiringOrganization_type}
 * - {@link manufacturer_type}
 * - {@link member_type}
 * - {@link memberOf_type}
 * - {@link offeredBy_type}
 * - {@link organizer_type}
 * - {@link performer_type}
 * - {@link publisher_type}
 * - {@link sponsor_type}

			 * @see http://schema.org/Organization
			 */
			export interface Organization extends Thing {
				
					address?: address_type
				
					award?: award_type
				
					brand?: brand_type
				
					contactPoint?: contactPoint_type
				
					email?: email_type
				
					event?: event_type
				
					funder?: funder_type
				
					location?: location_type
				
					logo?: logo_type
				
					makesOffer?: makesOffer_type
				
					member?: member_type
				
					memberOf?: memberOf_type
				
					sponsor?: sponsor_type
				
					telephone?: telephone_type
				
			}
		
			/**
			 * A person (alive, dead, undead, or fictional).
			 *
			 * 
			 * *(Non-Normative):* May appear as values of:
 * - {@link agent_type}
 * - {@link creator_type}
 * - {@link funder_type}
 * - {@link member_type}
 * - {@link offeredBy_type}
 * - {@link organizer_type}
 * - {@link performer_type}
 * - {@link publisher_type}
 * - {@link sponsor_type}

			 * @see http://schema.org/Person
			 */
			export interface Person extends Thing {
				
					additionalName?: additionalName_type
				
					address?: address_type
				
					affiliation?: affiliation_type
				
					award?: award_type
				
					brand?: brand_type
				
					contactPoint?: contactPoint_type
				
					email?: email_type
				
					familyName?: familyName_type
				
					funder?: funder_type
				
					givenName?: givenName_type
				
					height?: height_type
				
					honorificPrefix?: honorificPrefix_type
				
					honorificSuffix?: honorificSuffix_type
				
					jobTitle?: jobTitle_type
				
					makesOffer?: makesOffer_type
				
					memberOf?: memberOf_type
				
					sponsor?: sponsor_type
				
					telephone?: telephone_type
				
					weight?: weight_type
				
			}
		
			/**
			 * Entities that have a somewhat fixed, physical extension.
			 *
			 * *(Non-Normative):* Known subclasses:
 * - {@link Accommodation}
 * - {@link AdministrativeArea}

			 * *(Non-Normative):* May appear as values of:
 * - {@link jobLocation_type}
 * - {@link location_type}

			 * @see http://schema.org/Place
			 */
			export interface Place extends Thing {
				
					additionalProperty?: additionalProperty_type
				
					address?: address_type
				
					event?: event_type
				
					geo?: geo_type
				
					logo?: logo_type
				
					photo?: photo_type
				
					telephone?: telephone_type
				
			}
		
			/**
			 * The mailing address.
			 *
			 * 
			 * *(Non-Normative):* May appear as values of:
 * - {@link address_type}
 * - {@link location_type}

			 * @see http://schema.org/PostalAddress
			 */
			export interface PostalAddress extends ContactPoint {
				
					addressCountry?: addressCountry_type
				
					addressLocality?: addressLocality_type
				
					addressRegion?: addressRegion_type
				
					postOfficeBoxNumber?: postOfficeBoxNumber_type
				
					postalCode?: postalCode_type
				
					streetAddress?: streetAddress_type
				
			}
		
			/**
			 * A structured value representing a price or price range. Typically, only the subclasses of this type are used for markup.
			 *
			 * *(Non-Normative):* Known subclasses:
 * - {@link CompoundPriceSpecification}
 * - {@link UnitPriceSpecification}

			 * *(Non-Normative):* May appear as values of:
 * - {@link priceSpecification_type}

			 * @see http://schema.org/PriceSpecification
			 */
			export interface PriceSpecification extends StructuredValue {
				
					maxPrice?: maxPrice_type
				
					minPrice?: minPrice_type
				
					price?: price_type
				
					priceCurrency?: priceCurrency_type
				
			}
		
			/**
			 * Any offered product or service.
			 *
			 * 
			 * 
			 * @see http://schema.org/Product
			 */
			export interface Product extends Thing {
				
					additionalProperty?: additionalProperty_type
				
					award?: award_type
				
					brand?: brand_type
				
					color?: color_type
				
					depth?: depth_type
				
					height?: height_type
				
					logo?: logo_type
				
					manufacturer?: manufacturer_type
				
					offers?: offers_type
				
					productID?: productID_type
				
					sku?: sku_type
				
					weight?: weight_type
				
					width?: width_type
				
			}
		
			/**
			 * A property-value pair, e.g. representing a feature of a product or place. Use the `name` property for the name of the property. If there is an additional human-readable version of the value, put that into the `description` property.
			 *
			 * 
			 * *(Non-Normative):* May appear as values of:
 * - {@link additionalProperty_type}
 * - {@link identifier_type}

			 * @see http://schema.org/PropertyValue
			 */
			export interface PropertyValue extends StructuredValue {
				
					maxValue?: maxValue_type
				
					minValue?: minValue_type
				
					unitCode?: unitCode_type
				
					unitText?: unitText_type
				
					value?: value_type
				
			}
		
			/**
			 * A part of a successively published publication such as a periodical or publication volume, often numbered, usually containing a grouping of works such as articles.
			 *
			 * 
			 * 
			 * @see http://schema.org/PublicationIssue
			 */
			export interface PublicationIssue extends CreativeWork {
				
			}
		
			/**
			 * A point value or interval for product characteristics and other purposes.
			 *
			 * 
			 * *(Non-Normative):* May appear as values of:
 * - {@link depth_type}
 * - {@link height_type}
 * - {@link recipeYield_type}
 * - {@link weight_type}
 * - {@link width_type}
 * - {@link yield_type}

			 * @see http://schema.org/QuantitativeValue
			 */
			export interface QuantitativeValue extends StructuredValue {
				
					additionalProperty?: additionalProperty_type
				
					maxValue?: maxValue_type
				
					minValue?: minValue_type
				
					unitCode?: unitCode_type
				
					unitText?: unitText_type
				
					value?: value_type
				
			}
		
			/**
			 * A rating is an evaluation on a numeric scale, such as 1 to 5 stars.
			 *
			 * 
			 * *(Non-Normative):* May appear as values of:
 * - {@link starRating_type}

			 * @see http://schema.org/Rating
			 */
			export interface Rating extends Intangible {
				
					bestRating?: bestRating_type
				
					ratingValue?: ratingValue_type
				
					worstRating?: worstRating_type
				
			}
		
			/**
			 * A recipe.
			 *
			 * 
			 * 
			 * @see http://schema.org/Recipe
			 */
			export interface Recipe extends HowTo {
				
					recipeIngredient?: recipeIngredient_type
				
					recipeYield?: recipeYield_type
				
			}
		
			/**
			 * A state or province of a country.
			 *
			 * 
			 * 
			 * @see http://schema.org/State
			 */
			export interface State extends AdministrativeArea {
				
			}
		
			/**
			 * Structured values are used when the value of a property has a more complex structure than simply being a textual value or a reference to another thing.
			 *
			 * *(Non-Normative):* Known subclasses:
 * - {@link ContactPoint}
 * - {@link GeoCoordinates}
 * - {@link PriceSpecification}
 * - {@link PropertyValue}
 * - {@link QuantitativeValue}

			 * *(Non-Normative):* May appear as values of:
 * - {@link value_type}

			 * @see http://schema.org/StructuredValue
			 */
			export interface StructuredValue extends Intangible {
				
			}
		
			/**
			 * The most generic type of item.
			 *
			 * *(Non-Normative):* Known subclasses:
 * - {@link Action}
 * - {@link CreativeWork}
 * - {@link Event}
 * - {@link Intangible}
 * - {@link Organization}
 * - {@link Person}
 * - {@link Place}
 * - {@link Product}

			 * *(Non-Normative):* May appear as values of:
 * - {@link item_type}
 * - {@link itemListElement_type}
 * - {@link mainEntity_type}

			 * @see http://schema.org/Thing
			 */
			export interface Thing extends JSONLDObject {
				
					additionalType?: additionalType_type
				
					description?: description_type
				
					disambiguatingDescription?: disambiguatingDescription_type
				
					identifier?: identifier_type
				
					image?: image_type
				
					mainEntityOfPage?: mainEntityOfPage_type
				
					name?: name_type
				
					potentialAction?: potentialAction_type
				
					sameAs?: sameAs_type
				
					url?: url_type
				
			}
		
			/**
			 * The price asked for a given offer by the respective organization or person.
			 *
			 * 
			 * *(Non-Normative):* May appear as values of:
 * - {@link priceComponent_type}

			 * @see http://schema.org/UnitPriceSpecification
			 */
			export interface UnitPriceSpecification extends PriceSpecification {
				
					unitCode?: unitCode_type
				
					unitText?: unitText_type
				
			}
		
			/**
			 * A web page. Every web page is implicitly assumed to be declared to be of type WebPage, so the various properties about that webpage, such as breadcrumb may be used. We recommend explicit declaration if these properties are specified, but if they are found outside of an itemscope, they will be assumed to be about the page.
			 *
			 * 
			 * 
			 * @see http://schema.org/WebPage
			 */
			export interface WebPage extends CreativeWork {
				
					significantLink?: significantLink_type
				
			}
		
			/**
			 * A web page element, like a table or an image.
			 *
			 * 
			 * 
			 * @see http://schema.org/WebPageElement
			 */
			export interface WebPageElement extends CreativeWork {
				
			}
		
			/**
			 * A WebSite is a set of related web pages and other items typically served from a single web domain and accessible via URLs.
			 *
			 * 
			 * 
			 * @see http://schema.org/WebSite
			 */
			export interface WebSite extends CreativeWork {
				
			}
		
			/**
			 * An additional name for a Person, can be used for a middle name.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Person}

			 * @see http://schema.org/additionalName
			 */
			type additionalName_type = Text|(Text)[]
		
			/**
			 * A property-value pair representing an additional characteristics of the entitity, e.g. a product feature or another characteristic for which there is no matching property in schema.org.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Place}
 * - {@link Product}
 * - {@link QuantitativeValue}

			 * @see http://schema.org/additionalProperty
			 */
			type additionalProperty_type = PropertyValue
		
			/**
			 * An additional type for the item, typically used for adding more specific types from external vocabularies in microdata syntax. This is a relationship between something and a class that the thing is in.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Thing}

			 * @see http://schema.org/additionalType
			 */
			type additionalType_type = URL|(URL)[]
		
			/**
			 * Physical address of the item.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link GeoCoordinates}
 * - {@link Organization}
 * - {@link Person}
 * - {@link Place}

			 * @see http://schema.org/address
			 */
			type address_type = PostalAddress|Text
		
			/**
			 * The country.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link PostalAddress}

			 * @see http://schema.org/addressCountry
			 */
			type addressCountry_type = Text
		
			/**
			 * The locality.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link PostalAddress}

			 * @see http://schema.org/addressLocality
			 */
			type addressLocality_type = Text
		
			/**
			 * The region.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link PostalAddress}

			 * @see http://schema.org/addressRegion
			 */
			type addressRegion_type = Text
		
			/**
			 * An organization that this person is affiliated with. For example, a school/university, a club, or a team.
			 *
			 * Extends {@link memberOf}
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Person}

			 * @see http://schema.org/affiliation
			 */
			type affiliation_type = Organization|(Organization)[]
		
			/**
			 * The direct performer or driver of the action (animate or inanimate). e.g. <em>John</em> wrote a book.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Action}

			 * @see http://schema.org/agent
			 */
			type agent_type = Organization|Person
		
			/**
			 * The end of the availability of the product or service included in the offer.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Offer}

			 * @see http://schema.org/availabilityEnds
			 */
			type availabilityEnds_type = DateTime
		
			/**
			 * The beginning of the availability of the product or service included in the offer.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Offer}

			 * @see http://schema.org/availabilityStarts
			 */
			type availabilityStarts_type = DateTime
		
			/**
			 * A language someone may use with or at the item, service or place. Please use one of the language codes from the [IETF BCP 47 standard](http://tools.ietf.org/html/bcp47).
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link LodgingBusiness}

			 * @see http://schema.org/availableLanguage
			 */
			type availableLanguage_type = Text|(Text)[]
		
			/**
			 * An award won by or for this item.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Organization}
 * - {@link Person}
 * - {@link Product}

			 * @see http://schema.org/award
			 */
			type award_type = Text|(Text)[]
		
			/**
			 * The highest value allowed in this rating system. If bestRating is omitted, 5 is assumed.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Rating}

			 * @see http://schema.org/bestRating
			 */
			type bestRating_type = Number|Text
		
			/**
			 * The brand(s) associated with a product or service, or the brand(s) maintained by an organization or business person.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Organization}
 * - {@link Person}
 * - {@link Product}

			 * @see http://schema.org/brand
			 */
			type brand_type = Brand|Organization|(Brand|Organization)[]
		
			/**
			 * The earliest someone may check into a lodging establishment.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link LodgingBusiness}

			 * @see http://schema.org/checkinTime
			 */
			type checkinTime_type = DateTime
		
			/**
			 * The latest someone may check out of a lodging establishment.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link LodgingBusiness}

			 * @see http://schema.org/checkoutTime
			 */
			type checkoutTime_type = DateTime
		
			/**
			 * The color of the product.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Product}

			 * @see http://schema.org/color
			 */
			type color_type = Text|(Text)[]
		
			/**
			 * A contact point for a person or organization.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Organization}
 * - {@link Person}

			 * @see http://schema.org/contactPoint
			 */
			type contactPoint_type = ContactPoint|(ContactPoint)[]
		
			/**
			 * The creator/author of this CreativeWork.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link CreativeWork}

			 * @see http://schema.org/creator
			 */
			type creator_type = Organization|Person
		
			/**
			 * The currency accepted.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link LocalBusiness}

			 * @see http://schema.org/currenciesAccepted
			 */
			type currenciesAccepted_type = Text|(Text)[]
		
			/**
			 * The date on which the CreativeWork was created or the item was added to a DataFeed.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link CreativeWork}

			 * @see http://schema.org/dateCreated
			 */
			type dateCreated_type = Date|DateTime
		
			/**
			 * The date on which the CreativeWork was most recently modified or when the item’s entry was modified within a DataFeed.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link CreativeWork}

			 * @see http://schema.org/dateModified
			 */
			type dateModified_type = Date|DateTime|(Date|DateTime)[]
		
			/**
			 * Date of first broadcast/publication.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link CreativeWork}

			 * @see http://schema.org/datePublished
			 */
			type datePublished_type = Date
		
			/**
			 * The depth of the item.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Product}

			 * @see http://schema.org/depth
			 */
			type depth_type = QuantitativeValue
		
			/**
			 * A description of the item.
			 *
			 * 
			 * *(Non-Normative):* Known subproperties:
 * - {@link disambiguatingDescription}

			 * *(Non-Normative):* Property of:
 * - {@link Thing}

			 * @see http://schema.org/description
			 */
			type description_type = Text|(Text)[]
		
			/**
			 * A short description of the item used to disambiguate from other, similar items. Information from other properties (in particular, name) may be necessary for the description to be useful for disambiguation.
			 *
			 * Extends {@link description}
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Thing}

			 * @see http://schema.org/disambiguatingDescription
			 */
			type disambiguatingDescription_type = Text|(Text)[]
		
			/**
			 * The elevation of a location (WGS 84).
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link GeoCoordinates}

			 * @see http://schema.org/elevation
			 */
			type elevation_type = Number|Text
		
			/**
			 * Email address.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link ContactPoint}
 * - {@link Organization}
 * - {@link Person}

			 * @see http://schema.org/email
			 */
			type email_type = Text
		
			/**
			 * The end date and time of the item (in ISO 8601 date format).
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Event}

			 * @see http://schema.org/endDate
			 */
			type endDate_type = Date|DateTime
		
			/**
			 * The endTime of something.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Action}

			 * @see http://schema.org/endTime
			 */
			type endTime_type = DateTime
		
			/**
			 * Upcoming or past event associated with this place, organization, or action.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Organization}
 * - {@link Place}

			 * @see http://schema.org/event
			 */
			type event_type = Event|(Event)[]
		
			/**
			 * Family name. In the U.S., the last name of an Person. This can be used along with `givenName` instead of the `name` property.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Person}

			 * @see http://schema.org/familyName
			 */
			type familyName_type = Text
		
			/**
			 * A person or organization that supports (sponsors) something through some kind of financial contribution.
			 *
			 * Extends {@link sponsor}
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link CreativeWork}
 * - {@link Event}
 * - {@link Organization}
 * - {@link Person}

			 * @see http://schema.org/funder
			 */
			type funder_type = Organization|Person|(Organization|Person)[]
		
			/**
			 * The geo coordinates of the place.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Place}

			 * @see http://schema.org/geo
			 */
			type geo_type = GeoCoordinates
		
			/**
			 * Given name. In the U.S., the first name of a Person. This can be used along with `familyName` instead of the `name` property.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Person}

			 * @see http://schema.org/givenName
			 */
			type givenName_type = Text
		
			/**
			 * Indicates a CreativeWork that is (in some sense) a part of this CreativeWork.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link CreativeWork}

			 * @see http://schema.org/hasPart
			 */
			type hasPart_type = CreativeWork|(CreativeWork)[]
		
			/**
			 * Headline of the article.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link CreativeWork}

			 * @see http://schema.org/headline
			 */
			type headline_type = Text
		
			/**
			 * The height of the item.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link MediaObject}
 * - {@link Person}
 * - {@link Product}

			 * @see http://schema.org/height
			 */
			type height_type = QuantitativeValue
		
			/**
			 * Organization offering the job position.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link JobPosting}

			 * @see http://schema.org/hiringOrganization
			 */
			type hiringOrganization_type = Organization|(Organization)[]
		
			/**
			 * An honorific prefix preceding a Person’s name such as Dr/Mrs/Mr.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Person}

			 * @see http://schema.org/honorificPrefix
			 */
			type honorificPrefix_type = Text
		
			/**
			 * An honorific suffix preceding a Person’s name such as M.D./PhD/MSCSW.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Person}

			 * @see http://schema.org/honorificSuffix
			 */
			type honorificSuffix_type = Text
		
			/**
			 * The identifier property represents any kind of identifier for any kind of Thing, such as ISBNs, GTIN codes, UUIDs etc.
			 *
			 * 
			 * *(Non-Normative):* Known subproperties:
 * - {@link productID}
 * - {@link sku}

			 * *(Non-Normative):* Property of:
 * - {@link Thing}

			 * @see http://schema.org/identifier
			 */
			type identifier_type = PropertyValue|Text|URL
		
			/**
			 * An image of the item. This can be a URL or a fully described ImageObject.
			 *
			 * 
			 * *(Non-Normative):* Known subproperties:
 * - {@link logo}
 * - {@link photo}

			 * *(Non-Normative):* Property of:
 * - {@link Thing}

			 * @see http://schema.org/image
			 */
			type image_type = ImageObject|URL|(ImageObject|URL)[]
		
			/**
			 * Indicates a CreativeWork that this CreativeWork is (in some sense) part of.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link CreativeWork}

			 * @see http://schema.org/isPartOf
			 */
			type isPartOf_type = CreativeWork
		
			/**
			 * An entity represented by an entry in a list or data feed (e.g. an artist in a list of artists).
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link ListItem}

			 * @see http://schema.org/item
			 */
			type item_type = Thing
		
			/**
			 * For itemListElement values, you can use simple strings (e.g. "Peter", "Paul", "Mary"), existing entities, or use ListItem.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link ItemList}

			 * @see http://schema.org/itemListElement
			 */
			type itemListElement_type = ListItem|Text|Thing|(ListItem|Text|Thing)[]
		
			/**
			 * A (typically single) geographic location associated with the job position.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link JobPosting}

			 * @see http://schema.org/jobLocation
			 */
			type jobLocation_type = Place|(Place)[]
		
			/**
			 * The job title of the person (for example, Financial Manager).
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Person}

			 * @see http://schema.org/jobTitle
			 */
			type jobTitle_type = Text
		
			/**
			 * Keywords or tags used to describe this content. Multiple entries in a keywords list are typically delimited by commas.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link CreativeWork}

			 * @see http://schema.org/keywords
			 */
			type keywords_type = Text|(Text)[]
		
			/**
			 * The latitude of a location (WGS 84).
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link GeoCoordinates}

			 * @see http://schema.org/latitude
			 */
			type latitude_type = Number|Text
		
			/**
			 * The location of for example where the event is happening, an organization is located, or where an action takes place.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Action}
 * - {@link Event}
 * - {@link Organization}

			 * @see http://schema.org/location
			 */
			type location_type = Place|PostalAddress|Text|(Place|PostalAddress|Text)[]
		
			/**
			 * An associated logo.
			 *
			 * Extends {@link image}
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Brand}
 * - {@link Organization}
 * - {@link Place}
 * - {@link Product}

			 * @see http://schema.org/logo
			 */
			type logo_type = ImageObject|URL|(ImageObject|URL)[]
		
			/**
			 * The longitude of a location (WGS 84).
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link GeoCoordinates}

			 * @see http://schema.org/longitude
			 */
			type longitude_type = Number|Text
		
			/**
			 * Indicates the primary entity described in some page or other CreativeWork.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link CreativeWork}

			 * @see http://schema.org/mainEntity
			 */
			type mainEntity_type = Thing
		
			/**
			 * Indicates a page (or other CreativeWork) for which this thing is the main entity being described.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Thing}

			 * @see http://schema.org/mainEntityOfPage
			 */
			type mainEntityOfPage_type = CreativeWork|URL|(CreativeWork|URL)[]
		
			/**
			 * A pointer to products or services offered by the organization or person.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Organization}
 * - {@link Person}

			 * @see http://schema.org/makesOffer
			 */
			type makesOffer_type = Offer|(Offer)[]
		
			/**
			 * The manufacturer of the product.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Product}

			 * @see http://schema.org/manufacturer
			 */
			type manufacturer_type = Organization
		
			/**
			 * The highest price if the price is a range.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link PriceSpecification}

			 * @see http://schema.org/maxPrice
			 */
			type maxPrice_type = Number
		
			/**
			 * The upper value of some characteristic or property.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link PropertyValue}
 * - {@link QuantitativeValue}

			 * @see http://schema.org/maxValue
			 */
			type maxValue_type = Number
		
			/**
			 * A member of an Organization or a ProgramMembership. Organizations can be members of organizations; ProgramMembership is typically for individuals.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Organization}

			 * @see http://schema.org/member
			 */
			type member_type = Organization|Person|(Organization|Person)[]
		
			/**
			 * An Organization (or ProgramMembership) to which this Person or Organization belongs.
			 *
			 * 
			 * *(Non-Normative):* Known subproperties:
 * - {@link affiliation}

			 * *(Non-Normative):* Property of:
 * - {@link Organization}
 * - {@link Person}

			 * @see http://schema.org/memberOf
			 */
			type memberOf_type = Organization|(Organization)[]
		
			/**
			 * The lowest price if the price is a range.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link PriceSpecification}

			 * @see http://schema.org/minPrice
			 */
			type minPrice_type = Number
		
			/**
			 * The lower value of some characteristic or property.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link PropertyValue}
 * - {@link QuantitativeValue}

			 * @see http://schema.org/minValue
			 */
			type minValue_type = Number
		
			/**
			 * The name of the item.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Thing}

			 * @see http://schema.org/name
			 */
			type name_type = Text
		
			/**
			 * A link to the ListItem that follows the current one.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link ListItem}

			 * @see http://schema.org/nextItem
			 */
			type nextItem_type = ListItem
		
			/**
			 * The number of items in an ItemList. Note that some descriptions might not fully describe all items in a list (e.g., multi-page pagination); in such cases, the numberOfItems would be for the entire list.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link ItemList}

			 * @see http://schema.org/numberOfItems
			 */
			type numberOfItems_type = Integer
		
			/**
			 * The number of offers for the product.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link AggregateOffer}

			 * @see http://schema.org/offerCount
			 */
			type offerCount_type = Integer
		
			/**
			 * A pointer to the organization or person making the offer.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Offer}

			 * @see http://schema.org/offeredBy
			 */
			type offeredBy_type = Organization|Person
		
			/**
			 * An offer to provide this item—for example, an offer to sell a product, rent the DVD of a movie, perform a service, or give away tickets to an event.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link AggregateOffer}
 * - {@link CreativeWork}
 * - {@link Event}
 * - {@link Product}

			 * @see http://schema.org/offers
			 */
			type offers_type = Offer|(Offer)[]
		
			/**
			 * The general opening hours for a business. Opening hours can be specified as a weekly time range, starting with days, then times per day. Multiple days can be listed with commas ',' separating each day. Day or time ranges are specified using a hyphen '-'.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link LocalBusiness}

			 * @see http://schema.org/openingHours
			 */
			type openingHours_type = Text|(Text)[]
		
			/**
			 * An organizer of an Event.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Event}

			 * @see http://schema.org/organizer
			 */
			type organizer_type = Organization|Person|(Organization|Person)[]
		
			/**
			 * Cash, Credit Card, Cryptocurrency, Local Exchange Tradings System, etc.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link LocalBusiness}

			 * @see http://schema.org/paymentAccepted
			 */
			type paymentAccepted_type = Text|(Text)[]
		
			/**
			 * A performer at the event—for example, a presenter, musician, musical group or actor.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Event}

			 * @see http://schema.org/performer
			 */
			type performer_type = Organization|Person|(Organization|Person)[]
		
			/**
			 * Indicates whether pets are allowed to enter the accommodation or lodging business. More detailed information can be put in a text value.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link LodgingBusiness}

			 * @see http://schema.org/petsAllowed
			 */
			type petsAllowed_type = Boolean|Text
		
			/**
			 * A photograph of this place.
			 *
			 * Extends {@link image}
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Place}

			 * @see http://schema.org/photo
			 */
			type photo_type = ImageObject|(ImageObject)[]
		
			/**
			 * The position of an item in a series or sequence of items.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link CreativeWork}
 * - {@link ListItem}

			 * @see http://schema.org/position
			 */
			type position_type = Integer|Text
		
			/**
			 * The post office box number for PO box addresses.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link PostalAddress}

			 * @see http://schema.org/postOfficeBoxNumber
			 */
			type postOfficeBoxNumber_type = Text
		
			/**
			 * The postal code.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link PostalAddress}

			 * @see http://schema.org/postalCode
			 */
			type postalCode_type = Text
		
			/**
			 * Indicates a potential Action, which describes an idealized action in which this thing would play an ‘object’ role.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Thing}

			 * @see http://schema.org/potentialAction
			 */
			type potentialAction_type = Action|(Action)[]
		
			/**
			 * A link to the ListItem that precedes the current one.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link ListItem}

			 * @see http://schema.org/previousItem
			 */
			type previousItem_type = ListItem
		
			/**
			 * The offer price of a product, or of a price component when attached to `PriceSpecification` and its subtypes.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Offer}
 * - {@link PriceSpecification}

			 * @see http://schema.org/price
			 */
			type price_type = Number|Text
		
			/**
			 * This property links to all `UnitPriceSpecification` nodes that apply in parallel for the `CompoundPriceSpecification` node.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link CompoundPriceSpecification}

			 * @see http://schema.org/priceComponent
			 */
			type priceComponent_type = UnitPriceSpecification|(UnitPriceSpecification)[]
		
			/**
			 * The currency (in 3-letter ISO 4217 format) of the price or a price component, when attached to `PriceSpecification` and its subtypes.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Offer}
 * - {@link PriceSpecification}

			 * @see http://schema.org/priceCurrency
			 */
			type priceCurrency_type = Text
		
			/**
			 * The price range of the business, for example `$$$`.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link LocalBusiness}

			 * @see http://schema.org/priceRange
			 */
			type priceRange_type = Text|(Text)[]
		
			/**
			 * One or more detailed price specifications, indicating the unit price and delivery or payment charges.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Offer}

			 * @see http://schema.org/priceSpecification
			 */
			type priceSpecification_type = PriceSpecification|(PriceSpecification)[]
		
			/**
			 * The product identifier, such as ISBN.
			 *
			 * Extends {@link identifier}
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Product}

			 * @see http://schema.org/productID
			 */
			type productID_type = Text
		
			/**
			 * The publisher of the creative work.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link CreativeWork}

			 * @see http://schema.org/publisher
			 */
			type publisher_type = Organization|Person
		
			/**
			 * The rating for the content.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Rating}

			 * @see http://schema.org/ratingValue
			 */
			type ratingValue_type = Number|Text
		
			/**
			 * A single ingredient used in the recipe, e.g. sugar, flour or garlic.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Recipe}

			 * @see http://schema.org/recipeIngredient
			 */
			type recipeIngredient_type = Text|(Text)[]
		
			/**
			 * The quantity produced by the recipe (for example, number of people served, number of servings, etc).
			 *
			 * Extends {@link yield}
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Recipe}

			 * @see http://schema.org/recipeYield
			 */
			type recipeYield_type = QuantitativeValue|Text
		
			/**
			 * Responsibilities associated with this role or Occupation.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link JobPosting}

			 * @see http://schema.org/responsibilities
			 */
			type responsibilities_type = Text|(Text)[]
		
			/**
			 * URL of a reference Web page that unambiguously indicates the item’s identity. E.g. the URL of the item’s Wikipedia page, Wikidata entry, or official website.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Thing}

			 * @see http://schema.org/sameAs
			 */
			type sameAs_type = URL|(URL)[]
		
			/**
			 * One of the more significant URLs on the page. Typically, these are the non-navigation links that are clicked on the most.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link WebPage}

			 * @see http://schema.org/significantLink
			 */
			type significantLink_type = URL|(URL)[]
		
			/**
			 * The Stock Keeping Unit (SKU), i.e. a merchant-specific identifier for a product or service, or the product to which the offer refers.
			 *
			 * Extends {@link identifier}
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Product}

			 * @see http://schema.org/sku
			 */
			type sku_type = Text
		
			/**
			 * A person or organization that supports a thing through a pledge, promise, or financial contribution. e.g. a sponsor of a Medical Study or a corporate sponsor of an event.
			 *
			 * 
			 * *(Non-Normative):* Known subproperties:
 * - {@link funder}

			 * *(Non-Normative):* Property of:
 * - {@link CreativeWork}
 * - {@link Event}
 * - {@link Organization}
 * - {@link Person}

			 * @see http://schema.org/sponsor
			 */
			type sponsor_type = Organization|Person|(Organization|Person)[]
		
			/**
			 * An official rating for a lodging business or food establishment, e.g. from national associations or standards bodies. Use the author property to indicate the rating organization, e.g. as an Organization with name such as (e.g. HOTREC, DEHOGA, WHR, or Hotelstars).
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link LodgingBusiness}

			 * @see http://schema.org/starRating
			 */
			type starRating_type = Rating|(Rating)[]
		
			/**
			 * The start date and time of the item (in ISO 8601 date format).
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Event}

			 * @see http://schema.org/startDate
			 */
			type startDate_type = Date|DateTime
		
			/**
			 * The startTime of something.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Action}

			 * @see http://schema.org/startTime
			 */
			type startTime_type = DateTime
		
			/**
			 * The street address.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link PostalAddress}

			 * @see http://schema.org/streetAddress
			 */
			type streetAddress_type = Text
		
			/**
			 * An Event that is part of this event. For example, a conference event includes many presentations, each of which is a subEvent of the conference.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Event}

			 * @see http://schema.org/subEvent
			 */
			type subEvent_type = Event|(Event)[]
		
			/**
			 * An event that this event is a part of. For example, a collection of individual music performances might each have a music festival as their superEvent.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Event}

			 * @see http://schema.org/superEvent
			 */
			type superEvent_type = Event|(Event)[]
		
			/**
			 * The telephone number.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link ContactPoint}
 * - {@link Organization}
 * - {@link Person}
 * - {@link Place}

			 * @see http://schema.org/telephone
			 */
			type telephone_type = Text
		
			/**
			 * The textual content of this CreativeWork.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link CreativeWork}

			 * @see http://schema.org/text
			 */
			type text_type = Text
		
			/**
			 * A thumbnail image relevant to the Thing.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link CreativeWork}

			 * @see http://schema.org/thumbnailUrl
			 */
			type thumbnailUrl_type = URL
		
			/**
			 * The title of the job.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link JobPosting}

			 * @see http://schema.org/title
			 */
			type title_type = Text
		
			/**
			 * The unit of measurement given using the UN/CEFACT Common Code (3 characters) or a URL. Other codes than the UN/CEFACT Common Code may be used with a prefix followed by a colon.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link PropertyValue}
 * - {@link QuantitativeValue}
 * - {@link UnitPriceSpecification}

			 * @see http://schema.org/unitCode
			 */
			type unitCode_type = Text|URL
		
			/**
			 * A string or text indicating the unit of measurement. Useful if you cannot provide a standard unit code for `unitCode`.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link PropertyValue}
 * - {@link QuantitativeValue}
 * - {@link UnitPriceSpecification}

			 * @see http://schema.org/unitText
			 */
			type unitText_type = Text
		
			/**
			 * URL of the item.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Thing}

			 * @see http://schema.org/url
			 */
			type url_type = URL
		
			/**
			 * The value of the quantitative value or property value node.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link PropertyValue}
 * - {@link QuantitativeValue}

			 * @see http://schema.org/value
			 */
			type value_type = Boolean|Number|StructuredValue|Text
		
			/**
			 * The weight of the product or person.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Person}
 * - {@link Product}

			 * @see http://schema.org/weight
			 */
			type weight_type = QuantitativeValue
		
			/**
			 * The width of the item.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link MediaObject}
 * - {@link Product}

			 * @see http://schema.org/width
			 */
			type width_type = QuantitativeValue
		
			/**
			 * The lowest value allowed in this rating system. If worstRating is omitted, 1 is assumed.
			 *
			 * 
			 * 
			 * *(Non-Normative):* Property of:
 * - {@link Rating}

			 * @see http://schema.org/worstRating
			 */
			type worstRating_type = Number|Text
		
			/**
			 * The quantity that results by performing instructions. For example, a paper airplane, 10 personalized candles.
			 *
			 * 
			 * *(Non-Normative):* Known subproperties:
 * - {@link recipeYield}

			 * *(Non-Normative):* Property of:
 * - {@link HowTo}

			 * @see http://schema.org/yield
			 */
			type yield_type = QuantitativeValue|Text
		